pub struct LnRpcTracked {
pub(crate) inner: Arc<dyn ILnRpcClient>,
pub(crate) name: &'static str,
}Expand description
A wrapper around Arc<dyn ILnRpcClient> that tracks metrics for each RPC
call.
This wrapper records the duration and success/error status of each Lightning RPC call to Prometheus metrics, allowing monitoring of Lightning node connectivity and performance.
Note: This wrapper is designed to wrap the Arc<dyn ILnRpcClient> returned
from route_htlcs. Calling route_htlcs on this wrapper will panic, as
route_htlcs should only be called once on the original client before
wrapping.
Fields
inner: Arc<dyn ILnRpcClient>name: &'static strImplementations
Sourceimpl LnRpcTracked
impl LnRpcTracked
Sourcepub fn new(
inner: Arc<dyn ILnRpcClient>,
name: &'static str,
) -> Arc<dyn ILnRpcClient>
pub fn new( inner: Arc<dyn ILnRpcClient>, name: &'static str, ) -> Arc<dyn ILnRpcClient>
Wraps an Arc<dyn ILnRpcClient> with metrics tracking.
The name parameter is used to distinguish different uses of the
Lightning RPC client in metrics (e.g., “gateway”).
pub(crate) fn record_call<T, E>(&self, method: &str, result: &Result<T, E>)